@@ -1,11 +1,7 @@
-// SPDX-FileCopyrightText: 2021 Agathe Porte <microjoe@microjoe.org>
-//
-// SPDX-License-Identifier: Apache-2.0 OR MIT
-
 use gio::prelude::*;
 use gtk::prelude::*;
 
-use gladis::Gladis;
+use gladis4::Gladis;
 
 #[derive(Gladis, Clone)]
 struct Ui {
@@ -23,7 +19,7 @@ fn build_ui(app: &gtk::Application) {
         b.set_label("clicked!");
     });
 
-    ui.window.show_all();
+    ui.window.present();
 }
 
 fn main() {
